==> mobile_pos-0.8.12.tar.gz: lib/src/views/request_pos/widget/termianl_settings.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/request_pos/widget/disable_terminal_sheet.dart';
import 'package:mobile_pos/src/views/request_pos/widget/update_terminal_sheet.dart';

class TerminalSettings extends StatefulWidget {
  final TerminalModel model;
  final Function onUpdated;
  const TerminalSettings(
      {super.key, required this.model, required this.onUpdated});

  @override
  State<TerminalSettings> createState() => _TerminalSettingsState();
}

class _TerminalSettingsState extends State<TerminalSettings> {
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.symmetric(horizontal: kHoriontalScreenPadding),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          const Gap(16),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Row(
            children: [
              Expanded(
                child: Text(
                  "Terminal Settings",
                  style: headling1.copyWith(fontSize: 20),
                ),
              ),
              Container(
                  padding: const EdgeInsets.all(6),
                  height: 32,
                  width: 32,
                  decoration: BoxDecoration(
                      shape: BoxShape.circle, color: AppColors.ravenLightGrey4),
                  child: Image.asset(loadAsset("cancel_icon.png")))
            ],
          ),
          const Gap(28),
          ItemWidget(
            name: "Edit terminal label",
            onTap: () {
              Navigator.pop(context);
              showRavenPayBottomSheet(context,
                  child: UpdateTerminalInfo(
                    model: widget.model,
                    onUpdated: widget.onUpdated,
                  ));
            },
            asset: "edit_icon2",
          ),
          const Divider(
            height: 36,
          ),
          ItemWidget(
            name: "Raise an issue or complaint",
            onTap: () {
              Navigator.pop(context);
            },
            asset: "info_icon",
          ),
          const Divider(
            height: 36,
          ),
          ItemWidget(
            name: "Disable this terminal",
            onTap: () {
              Navigator.pop(context);
              showRavenPayBottomSheet(context,
                  child: DisableTerminalSheet(model: widget.model));
            },
            asset: "cancel_icon",
            color: AppColors.ravenRed,
          ),
          const Gap(30),
        ],
      ),
    );
  }
}

class ItemWidget extends StatelessWidget {
  final String name;
  final String asset;
  final Function onTap;
  final Color? color;
  const ItemWidget(
      {super.key,
      required this.name,
      this.color,
      required this.onTap,
      required this.asset});

  @override
  Widget build(BuildContext context) {
    return InkWell(
      splashColor: Colors.transparent,
      highlightColor: Colors.transparent,
      onTap: () => onTap(),
      child: Row(
        children: [
          Image.asset(
            loadAsset("$asset.png"),
            color: color,
            height: 20,
          ),
          const Gap(16),
          Expanded(
              child: Text(name,
                  style: subtitle2.copyWith(
                      fontSize: 14, color: color ?? AppColors.ravenDark)))
        ],
      ),
    );
  }
}

==> mobile_pos-0.8.18.tar.gz: lib/src/views/request_pos/widget/termianl_settings.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/request_pos/widget/disable_terminal_sheet.dart';
import 'package:mobile_pos/src/views/request_pos/widget/update_terminal_sheet.dart';

class TerminalSettings extends StatefulWidget {
  final TerminalModel model;
  final Function onUpdated;
  const TerminalSettings(
      {super.key, required this.model, required this.onUpdated});

  @override
  State<TerminalSettings> createState() => _TerminalSettingsState();
}

class _TerminalSettingsState extends State<TerminalSettings> {
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.symmetric(horizontal: kHoriontalScreenPadding),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          const Gap(16),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Row(
            children: [
              Expanded(
                child: Text(
                  "Terminal Settings",
                  style: headling1.copyWith(fontSize: 20),
                ),
              ),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: Container(
                    padding: const EdgeInsets.all(6),
                    height: 32,
                    width: 32,
                    decoration: BoxDecoration(
                        shape: BoxShape.circle,
                        color: AppColors.ravenLightGrey4),
                    child: Image.asset(loadAsset("cancel_icon.png"))),
              )
            ],
          ),
          const Gap(28),
          ItemWidget(
            name: "Edit terminal label",
            onTap: () {
              Navigator.pop(context);
              showRavenPayBottomSheet(context,
                  child: UpdateTerminalInfo(
                    model: widget.model,
                    onUpdated: widget.onUpdated,
                  ));
            },
            asset: "edit_icon2",
          ),
          const Divider(
            height: 36,
          ),
          ItemWidget(
            name: "Raise an issue or complaint",
            onTap: () {
              Navigator.pop(context);
            },
            asset: "info_icon",
          ),
          const Divider(
            height: 36,
          ),
          ItemWidget(
            name: "Disable this terminal",
            onTap: () {
              Navigator.pop(context);
              showRavenPayBottomSheet(context,
                  child: DisableTerminalSheet(model: widget.model));
            },
            asset: "cancel_icon",
            color: AppColors.ravenRed,
          ),
          const Gap(30),
        ],
      ),
    );
  }
}

class ItemWidget extends StatelessWidget {
  final String name;
  final String asset;
  final Function onTap;
  final Color? color;
  const ItemWidget(
      {super.key,
      required this.name,
      this.color,
      required this.onTap,
      required this.asset});

  @override
  Widget build(BuildContext context) {
    return InkWell(
      splashColor: Colors.transparent,
      highlightColor: Colors.transparent,
      onTap: () => onTap(),
      child: Row(
        children: [
          Image.asset(
            loadAsset("$asset.png"),
            color: color,
            height: 20,
          ),
          const Gap(16),
          Expanded(
              child: Text(name,
                  style: subtitle2.copyWith(
                      fontSize: 14, color: color ?? AppColors.ravenDark)))
        ],
      ),
    );
  }
}
